@@ -27,6 +27,7 @@ class DeviceType(Enum):
     Somfy = ApiDeviceType.SOMFY, "Somfy"
     IrDevice = ApiDeviceType.IR_DEVICE, "Infra Red Device"
     RollingScenario = ApiDeviceType.ROLLING_SCENARIO, "Rolling Scenario"
+    VRFAC = ApiDeviceType.VRF_AC, "VRF Unit"
 
     def __new__(cls, *args: Any, **kwds: Any):  # type: ignore
         obj = object.__new__(cls)
@@ -103,17 +104,17 @@ class SwitchBeeBaseSwitch(ABC):
 
     @state.setter
     def state(self, value: str | int) -> None:
-        if value == 0:
+        if value in [ApiStateCommand.OFF, 0]:
             self._state = ApiStateCommand.OFF
-        elif value == 100:
+        elif value in [ApiStateCommand.ON, 100]:
             self._state = ApiStateCommand.ON
-        else:
-            self._state = value
+        else:  # OFFLINE
+            self._state = -1
 
 
 @dataclass
 class SwitchBeeBaseShutter(ABC):
-    _position: int | None = field(init=False, repr=False, default=None)
+    _position: int | None = field(init=False, default=None)
 
     @property
     def position(self) -> int | None:
@@ -121,19 +122,20 @@ class SwitchBeeBaseShutter(ABC):
 
     @position.setter
     def position(self, value: str | int) -> None:
-
-        if value == ApiStateCommand.OFF:
-            self._position = 0
-        elif value == ApiStateCommand.ON:
-            self._position = 100
-        else:
+        if isinstance(value, int):
             self._position = int(value)
+        else:
+            if value == ApiStateCommand.ON:
+                self._position = 100
+            elif value == ApiStateCommand.OFF:
+                self._position = 0
+            else:  # OFFLINE
+                self._position = -1
 
 
 @dataclass
 class SwitchBeeBaseDimmer(ABC):
-
-    _brightness: int = field(init=False)
+    _brightness: int = field(init=False, repr=False)
 
     @property
     def brightness(self) -> int:
@@ -141,18 +143,21 @@ class SwitchBeeBaseDimmer(ABC):
 
     @brightness.setter
     def brightness(self, value: str | int) -> None:
-        if value == ApiStateCommand.OFF:
-            self._brightness = 0
-        elif value == ApiStateCommand.ON:
-            self._brightness = 100
-        else:
+        if isinstance(value, int):
             self._brightness = int(value)
+        else:
+            if value == ApiStateCommand.ON:
+                self._brightness = 100
+            elif value == ApiStateCommand.OFF:
+                self._brightness = 0
+            else:  # OFFLINE
+                self._brightness = -1
 
 
 @dataclass
 class SwitchBeeBaseTimer(ABC):
-    _minutes_left: int = field(init=False)
-    _state: str | int = field(init=False)
+    _minutes_left: int = field(init=False, repr=False)
+    _state: str | int = field(init=False, repr=False)
 
     @property
     def state(self) -> str | int:
@@ -160,11 +165,13 @@ class SwitchBeeBaseTimer(ABC):
 
     @state.setter
     def state(self, value: str | int) -> None:
-
         if value:
             if value == ApiStateCommand.OFF:
                 self._minutes_left = 0
                 self._state = value
+            elif value == ApiStateCommand.OFFLINE:
+                self._minutes_left = -1
+                self._state = value
             else:
                 self._minutes_left = int(value)
                 self._state = ApiStateCommand.ON
@@ -176,13 +183,12 @@ class SwitchBeeBaseTimer(ABC):
 
 @dataclass
 class SwitchBeeBaseThermostat(ABC):
-
     modes: List[str]
-    unit: str
-    mode: str = field(init=False)
-    fan: str = field(init=False)
-    target_temperature: int = field(init=False)
-    temperature: int = field(init=False)
+    temperature_unit: str
+    mode: str = field(init=False, repr=False)
+    fan: str = field(init=False, repr=False)
+    target_temperature: int = field(init=False, repr=False)
+    temperature: int = field(init=False, repr=False)
     max_temperature: int = 31
     min_temperature: int = 16
 
@@ -274,7 +280,7 @@ class SwitchBeeThermostat(
 ):
     def __post_init__(self) -> None:
         """Post initialization validate device type category as Thermostat."""
-        if self.type != DeviceType.Thermostat:
+        if self.type not in [DeviceType.Thermostat, DeviceType.VRFAC]:
             raise ValueError("only Thermostat are allowed")
         super().__post_init__()
 
